@@ -99,11 +99,11 @@ static char ** get_cal_flags(void) {
 		if ( str[i] == ',' )
 			++count;
 
-	flags = malloc((count + 1) * sizeof(char *));
+	flags = malloc((count + 2) * sizeof(char *));
 
 	begin = str;
 
-	for ( i = 0; i < count; ++i ) {
+	for ( i = 0; i < count+1; ++i ) {
 
 		end = strchr(begin, ',');
 
@@ -112,11 +112,14 @@ static char ** get_cal_flags(void) {
 
 		flags[i] = malloc(end-begin+1);
 		strncpy(flags[i], begin, end-begin);
+		flags[end-begin] = 0;
 
 		begin = end + 1;
 
 	}
 
+	flags[count+1] = NULL;
+
 	free(str);
 
 	return flags;
@@ -129,16 +132,19 @@ static unsigned int init(void) {
 
 	unsigned int ret = 0;
 	unsigned int i;
+	int skip;
+
+#ifdef WITH_LIBCAL
+	char ** cal_flags = get_cal_flags();
+	char ** cal_ptr;
+#endif
 
 	for ( i = 0; i < WD_COUNT; ++i ) {
 
-		int skip = 0;
+		skip = 0;
 
 #ifdef WITH_LIBCAL
 
-		char ** cal_flags = get_cal_flags();
-		char ** cal_ptr;
-
 		if ( wd[i].cal_flag && cal_flags ) {
 
 			cal_ptr = cal_flags;
@@ -177,6 +183,23 @@ static unsigned int init(void) {
 
 	}
 
+#ifdef WITH_LIBCAL
+
+	if ( cal_flags ) {
+
+		cal_ptr = cal_flags;
+
+		while ( *cal_ptr ) {
+			free(*cal_ptr);
+			++cal_ptr;
+		}
+
+		free(cal_flags);
+
+	}
+
+#endif
+
 	return ret;
 
 }
